summaryrefslogtreecommitdiff
path: root/distrib/atari/inst/install.sh
diff options
context:
space:
mode:
Diffstat (limited to 'distrib/atari/inst/install.sh')
-rw-r--r--distrib/atari/inst/install.sh15
1 files changed, 8 insertions, 7 deletions
diff --git a/distrib/atari/inst/install.sh b/distrib/atari/inst/install.sh
index cee17fa6614..51802b8f00a 100644
--- a/distrib/atari/inst/install.sh
+++ b/distrib/atari/inst/install.sh
@@ -1,5 +1,5 @@
#!/bin/sh
-# $OpenBSD: install.sh,v 1.2 1996/04/25 21:27:46 niklas Exp $
+#
# $NetBSD: install.sh,v 1.2 1995/08/25 19:17:28 leo Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
@@ -29,8 +29,9 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
# OpenBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.
@@ -94,9 +95,9 @@ prepdrive() {
esac
}
-echo "Welcome to the OpenBSD ${VERSION} installation program."
+echo "Welcome to the NetBSD ${VERSION} installation program."
echo ""
-echo "This program is designed to help you put OpenBSD on your hard disk,"
+echo "This program is designed to help you put NetBSD on your hard disk,"
echo "in a simple and rational way. Its main objective is to format,"
echo "mount and create an fstab for your root (/) and user (/usr)"
echo "partitions."
@@ -154,7 +155,7 @@ echo ""
echo "THIS IS YOUR LAST CHANCE!!!"
echo ""
echo "(answering yes will format your root partition on $rdev)"
-echo -n "Are you SURE you want OpenBSD installed on your hard drive? (yes/no) "
+echo -n "Are you SURE you want NetBSD installed on your hard drive? (yes/no) "
answer=""
while [ "$answer" = "" ]; do
getresp
@@ -261,11 +262,11 @@ echo " done."
echo ""
echo ""
echo "OK! The preliminary work of setting up your disk is now complete,"
-echo "and you can install the actual OpenBSD software."
+echo "and you can install the actual NetBSD software."
echo ""
echo "Right now, your root is mounted on /mnt and your usr on /mnt/usr."
echo "You should consult the installation notes to determine how to load"
-echo "and install the OpenBSD distribution sets, and how to configure your"
+echo "and install the NetBSD distribution sets, and how to configure your"
echo "system when you are done."
echo ""
echo "GOOD LUCK!"
@@ -29,8 +29,9 @@
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#
-# OpenBSD installation script.
+# NetBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.